@@ -46,6 +46,7 @@ setClassUnion("SubsetDef", c("expression", "logical", "integer", "numeric"))
 
 setClassUnion("integerOrNULL", c("NULL", "integer"))
 setClassUnion("characterOrNULL", c("NULL", "character"))
+setClassUnion("characterOrList", c("list", "character"))
 
 ## should XXX [splits, s_values, sval_labels, subset(?)] be a data.frame?
 setClass("TreePos", representation(
@@ -60,10 +61,29 @@ validity = function(object) {
 }
 )
 
+setOldClass(c("FormatList", "list"))
+
+FormatList <- function(..., .list = list(...)) {
+  if (!is.list(.list)) {
+    .list <- list(.list)
+  }
+  valid <- vapply(.list, is, class2 = "FormatSpec", TRUE)
+  if (!are(.list, "FormatSpec")) {
+    stop(
+      "Attempted to construct FormatList with elements that are not ",
+      "FormatSpec compatible. This should not happen, please contact ",
+      "the maintainers."
+    )
+  }
+
+  class(.list) <- c("FormatList", "list")
+  .list
+}
+
 setClassUnion("functionOrNULL", c("NULL", "function"))
 setClassUnion("listOrNULL", c("NULL", "list"))
 ## TODO (?) make "list" more specific, e.g FormatList, or FunctionList?
-setClassUnion("FormatSpec", c("NULL", "character", "function", "list"))
+setClassUnion("FormatSpec", c("NULL", "character", "function", "list", "FormatList"))
 setClassUnion("ExprOrNULL", c("NULL", "expression"))
 
 setClass("ValueWrapper", representation(
@@ -133,7 +153,7 @@ setClass("Split",
     name = "character",
     split_label = "character",
     split_format = "FormatSpec",
-    split_na_str = "character",
+    split_na_str = "characterOrList",
     split_label_position = "character",
     ## NB this is the function which is applied to
     ## get the content rows for the CHILDREN of this
@@ -633,7 +653,9 @@ setClass("VAnalyzeSplit",
   representation(
     default_rowlabel = "character",
     include_NAs = "logical",
-    var_label_position = "character"
+    var_label_position = "character",
+    row_formats_var = "characterOrNULL",
+    row_na_strs_var = "characterOrNULL"
   )
 )
 
@@ -672,7 +694,9 @@ AnalyzeVarSplit <- function(var,
                             indent_mod = 0L,
                             label_pos = "default",
                             cvar = "",
-                            section_div = NA_character_) {
+                            section_div = NA_character_,
+                            formats_var = NULL,
+                            na_strs_var = NULL) {
   check_ok_label(split_label)
   label_pos <- match.arg(label_pos, c("default", label_pos_values))
   if (!any(nzchar(defrowlab))) {
@@ -701,7 +725,9 @@ AnalyzeVarSplit <- function(var,
     page_title_prefix = NA_character_,
     child_section_div = section_div,
     child_show_colcounts = FALSE,
-    child_colcount_format = NA_character_
+    child_colcount_format = NA_character_,
+    row_formats_var = formats_var,
+    row_na_strs_var = na_strs_var
   ) ## no content_extra_args
 }
 
@@ -823,7 +849,9 @@ AnalyzeMultiVars <- function(var,
                              child_labels = c("default", "topleft", "visible", "hidden"),
                              child_names = var,
                              cvar = "",
-                             section_div = NA_character_) {
+                             section_div = NA_character_,
+                             formats_var = NULL,
+                             na_strs_var = NULL) {
   ## NB we used to resolve to strict TRUE/FALSE for label visibillity
   ## in this function but that was too greedy for repeated
   ## analyze calls, so that now occurs in the tabulation machinery
@@ -842,26 +870,59 @@ AnalyzeMultiVars <- function(var,
     ##        split_format = .repoutlst(split_format, nv)
     inclNAs <- .repoutlst(inclNAs, nv)
     section_div_if_multivar <- if (length(var) > 1) NA_character_ else section_div
-    pld <- mapply(AnalyzeVarSplit,
-      var = var,
-      split_name = child_names,
-      split_label = split_label,
-      afun = afun,
-      defrowlab = defrowlab,
-      cfun = cfun,
-      cformat = cformat,
-      ##                     split_format = split_format,
-      inclNAs = inclNAs,
-      MoreArgs = list(
-        extra_args = extra_args,
-        indent_mod = indent_mod,
-        label_pos = show_kidlabs,
-        split_format = split_format,
-        split_na_str = split_na_str,
-        section_div = section_div_if_multivar
-      ), ## rvis),
-      SIMPLIFY = FALSE
+
+    moreargs <- list(
+      extra_args = extra_args,
+      indent_mod = indent_mod,
+      label_pos = show_kidlabs,
+      section_div = section_div_if_multivar,
+      formats_var = formats_var,
+      na_strs_var = na_strs_var
     )
+    mv_list_case <- is.list(split_format) &&
+      all(var %in% names(split_format)) &&
+      all(vapply(split_format, is, class2 = "FormatList", TRUE))
+    if (mv_list_case) { # diff format list for each var
+      stopifnot(all(var %in% names(split_na_str)))
+      ## split_value does *not* go  in more args, not constant across vars
+      pld <- mapply(
+        AnalyzeVarSplit,
+        var = var,
+        split_name = child_names,
+        split_label = split_label,
+        afun = afun,
+        defrowlab = defrowlab,
+        cfun = cfun,
+        cformat = cformat,
+        ## in case they're in the wrong order for some insane reason
+        split_format = split_format[var],
+        split_na_str = split_na_str[var],
+        inclNAs = inclNAs,
+        MoreArgs = moreargs, ## rvis),
+        SIMPLIFY = FALSE
+      )
+    } else { # not diff lists for each var
+      ## split format goes in more args because its constant across vars
+      pld <- mapply(
+        AnalyzeVarSplit,
+        var = var,
+        split_name = child_names,
+        split_label = split_label,
+        afun = afun,
+        defrowlab = defrowlab,
+        cfun = cfun,
+        cformat = cformat,
+        inclNAs = inclNAs,
+        MoreArgs = c(
+          moreargs,
+          list(
+            split_format = split_format,
+            split_na_str = split_na_str
+          )
+        ), ## rvis),
+        SIMPLIFY = FALSE
+      )
+    }
   } else {
     ## we're combining existing splits here
     pld <- unlist(lapply(.payload, .uncompound))
@@ -1290,7 +1351,8 @@ setClass("VTableNodeInfo",
     format = "FormatSpec",
     na_str = "character",
     indent_modifier = "integer",
-    table_inset = "integer"
+    table_inset = "integer",
+    round_type = "character"
   )
 )
 
@@ -1313,7 +1375,8 @@ setClass("TableRow",
 #' @inheritParams constr_args
 #' @inheritParams lyt_args
 #' @param vis (`flag`)\cr whether the row should be visible (`LabelRow` only).
-#'
+#' @param round_type (`"iec"`, `"iec_mod"` or `"sas"`)\cr the type of rounding to perform.
+#' See [round_fmt()] for details.
 #' @return A formal object representing a table row of the constructed type.
 #'
 #' @author Gabriel Becker
@@ -1326,7 +1389,9 @@ LabelRow <- function(lev = 1L,
                      cinfo = EmptyColInfo,
                      indent_mod = 0L,
                      table_inset = 0L,
-                     trailing_section_div = NA_character_) {
+                     trailing_section_div = NA_character_,
+                     round_type = valid_round_type) {
+  round_type <- match.arg(round_type)
   check_ok_label(label)
   new("LabelRow",
     leaf_value = list(),
@@ -1340,7 +1405,8 @@ LabelRow <- function(lev = 1L,
     visible = vis,
     indent_modifier = as.integer(indent_mod),
     table_inset = as.integer(table_inset),
-    trailing_section_div = trailing_section_div
+    trailing_section_div = trailing_section_div,
+    round_type = round_type
   )
 }
 
@@ -1394,11 +1460,13 @@ setClass("LabelRow",
                       indent_mod = 0L,
                       footnotes = list(),
                       table_inset = 0L,
-                      trailing_section_div = NA_character_) {
+                      trailing_section_div = NA_character_,
+                      round_type = valid_round_type) {
+  round_type <- match.arg(round_type)
   if ((missing(name) || is.null(name) || is.na(name) || nchar(name) == 0) && !missing(label)) {
     name <- label
   }
-  vals <- lapply(vals, rcell)
+  vals <- lapply(vals, rcell, round_type = round_type)
   rlabels <- unique(unlist(lapply(vals, obj_label)))
   if ((missing(label) || is.null(label) || identical(label, "")) && sum(nzchar(rlabels)) == 1) {
     label <- rlabels[nzchar(rlabels)]
@@ -1422,7 +1490,8 @@ setClass("LabelRow",
     indent_modifier = indent_mod,
     row_footnotes = footnotes,
     table_inset = table_inset,
-    trailing_section_div = trailing_section_div
+    trailing_section_div = trailing_section_div,
+    round_type = round_type
   )
   rw <- set_format_recursive(rw, format, na_str, FALSE)
   rw
@@ -1571,6 +1640,22 @@ uniqify_child_names <- function(kidlst) {
   kidlst
 }
 
+# if input round_type is not defined (length 0) retrieve round_type from kids
+# and check all kids have the same round_type
+.determine_round_type <- function(round_type, kids) {
+  if (length(round_type) == 0) {
+    if ((length(kids) > 0)) {
+      round_type <- unique(vapply(kids, obj_round_type, ""))
+      stopifnot(length(round_type) == 1)
+    } else {
+      # no kids and round_type not set
+      ## continue with default value iec
+      round_type <- valid_round_type[1] # iec
+    }
+  }
+  round_type
+}
+
 
 #' Table constructors and classes
 #'
@@ -1607,7 +1692,9 @@ ElementaryTable <- function(kids = list(),
                             header_section_div = NA_character_,
                             hsep = default_hsep(),
                             trailing_section_div = NA_character_,
-                            inset = 0L) {
+                            inset = 0L,
+                            round_type = valid_round_type) {
+  round_type <- match.arg(round_type)
   check_ok_label(label)
   if (is.null(cinfo)) {
     if (length(kids) > 0) {
@@ -1641,7 +1728,8 @@ ElementaryTable <- function(kids = list(),
     provenance_footer = prov_footer,
     horizontal_sep = hsep,
     header_section_div = header_section_div,
-    trailing_section_div = trailing_section_div
+    trailing_section_div = trailing_section_div,
+    round_type = round_type
   )
   tab <- set_format_recursive(tab, format, na_str, FALSE)
   table_inset(tab) <- as.integer(inset)
@@ -1708,10 +1796,19 @@ TableTree <- function(kids = list(),
                       hsep = default_hsep(),
                       header_section_div = NA_character_,
                       trailing_section_div = NA_character_,
-                      inset = 0L) {
+                      inset = 0L,
+                      round_type = NULL) {
   check_ok_label(label)
   cinfo <- .calc_cinfo(cinfo, cont, kids)
 
+  # derive appropriate round_type to use
+  # either from input or retrieved from kids
+  round_type <- .determine_round_type(round_type, kids)
+  # also set this round_type to direct kids
+  # note that (some/most) obj_round_type setters will also set round_type of kids
+  # this will ensure only 1 round_type is present on all slots in the resulting tabletree
+  kids <- lapply(kids, `obj_round_type<-`, value = round_type)
+
   kids <- .enforce_valid_kids(kids, cinfo)
   if (isTRUE(iscontent) && !is.null(cont) && nrow(cont) > 0) {
     stop("Got table tree with content table and content position")
@@ -1742,7 +1839,8 @@ TableTree <- function(kids = list(),
       hsep = hsep,
       header_section_div = header_section_div,
       trailing_section_div = trailing_section_div,
-      inset = inset
+      inset = inset,
+      round_type = round_type
     )
   } else {
     tab <- new("TableTree",
@@ -1764,7 +1862,8 @@ TableTree <- function(kids = list(),
       page_title_prefix = page_title,
       horizontal_sep = "-",
       header_section_div = header_section_div,
-      trailing_section_div = trailing_section_div
+      trailing_section_div = trailing_section_div,
+      round_type = round_type
     ) ## this is overridden below to get recursiveness
     tab <- set_format_recursive(tab, format, na_str, FALSE)
 
@@ -1878,7 +1977,8 @@ setClass("PreDataTableLayouts",
     top_left = "character",
     header_section_div = "character",
     top_level_section_div = "character",
-    table_inset = "integer"
+    table_inset = "integer",
+    round_type = "character"
   )
 )
 
@@ -1891,7 +1991,9 @@ PreDataTableLayouts <- function(rlayout = PreDataRowLayout(),
                                 prov_footer = character(),
                                 header_section_div = NA_character_,
                                 top_level_section_div = NA_character_,
-                                table_inset = 0L) {
+                                table_inset = 0L,
+                                round_type = valid_round_type) {
+  round_type <- match.arg(round_type)
   new("PreDataTableLayouts",
     row_layout = rlayout,
     col_layout = clayout,
@@ -1902,7 +2004,8 @@ PreDataTableLayouts <- function(rlayout = PreDataRowLayout(),
     provenance_footer = prov_footer,
     header_section_div = header_section_div,
     top_level_section_div = top_level_section_div,
-    table_inset = table_inset
+    table_inset = table_inset,
+    round_type = round_type
   )
 }
 
@@ -1958,6 +2061,7 @@ RefFootnote <- function(note, index = NA_integer_, symbol = NA_character_) {
 #'
 #' @inheritParams lyt_args
 #' @inheritParams rcell
+#' @inheritParams gen_args
 #' @param val (`ANY`)\cr value in the cell exactly as it should be passed to a formatter or returned when extracted.
 #'
 #' @return An object representing the value within a single cell within a populated table. The underlying structure
@@ -1973,7 +2077,9 @@ RefFootnote <- function(note, index = NA_integer_, symbol = NA_character_) {
 ## indent_mod: indent modifier to be used for parent row
 CellValue <- function(val, format = NULL, colspan = 1L, label = NULL,
                       indent_mod = NULL, footnotes = NULL,
-                      align = NULL, format_na_str = NULL, stat_names = NA_character_) {
+                      align = NULL, format_na_str = NULL, stat_names = NA_character_,
+                      round_type = valid_round_type) {
+  round_type <- match.arg(round_type)
   if (is.null(colspan)) {
     colspan <- 1L
   }
@@ -1998,6 +2104,7 @@ CellValue <- function(val, format = NULL, colspan = 1L, label = NULL,
     align = align,
     format_na_str = format_na_str,
     stat_names = stat_names,
+    round_type = round_type,
     class = "CellValue"
   )
   ret
