@@ -47,6 +47,9 @@
 #'   wild-card path but resolve to an individual row will not be considered matching.
 #'   The value "elemtable" indicates an Elementary table, i.e., one representing a
 #'   single variable within an `analyze` call.
+#' @param round_type (`"iec"` (default), `"iec_mod"` or `"sas"`)\cr the type of rounding to perform.
+#' See [formatters::format_value()] for details.
+#'
 #'
 #' @return No return value.
 #'
@@ -57,6 +60,7 @@ gen_args <- function(df, alt_counts_df, spl, pos, tt, tr, verbose, colwidths, ob
                      value, object, path, label, label_pos, # visible_label,
                      cvar, topleft, page_prefix, hsep, indent_size, section_div, na_str, inset,
                      table_inset, tt_type = c("any", "row", "table", "elemtable"),
+                     round_type = valid_round_type,
                      ...) {
   NULL
 }
@@ -94,6 +98,14 @@ gen_args <- function(df, alt_counts_df, spl, pos, tt, tr, verbose, colwidths, ob
 #'   functions. See [formatters::list_valid_format_labels()] for a list of all available format strings.
 #' @param format_na_str (`string`)\cr string which should be displayed when formatted if this cell's value(s)
 #'   are all `NA`.
+#' @param formats_var (`string` or `NULL`)\cr `NULL` (the default) or the name of the list column containing named
+#' lists of default formats to use. These will be applied with the same precedence as the `format` argument; i.e.,
+#' they will not override formats (other than `"default"`) set within the afun.
+#' Cannot be used simultaneously with `format`.
+#' @param na_strs_var (`string` or `NULL`)\cr `NULL` (the default) or the name of the list column containing named
+#' lists of default NA strings to use. These will be applied with the same precedence as the `format` argument; i.e.,
+#' they will not override formats (other than `"default"`) set within the afun.
+#' Cannot be used simultaneously with `format`. Cannot be used if `formats_var` is `NULL`.
 #' @param indent_mod (`numeric`)\cr modifier for the default indent position for the structure created by this
 #'   function (subtable, content table, or row) *and all of that structure's children*. Defaults to 0, which
 #'   corresponds to the unmodified default behavior.
@@ -153,7 +165,7 @@ lyt_args <- function(lyt, var, vars, label, labels_var, varlabels, varnames, spl
                      var_labels, cvar,
                      table_names, topleft, align, page_by, page_prefix,
                      format_na_str, section_div, na_str, show_colcounts,
-                     colcount_format, parent_name) {
+                     colcount_format, parent_name, formats_var, na_strs_var) {
   NULL
 }
 
