@@ -1067,12 +1067,81 @@ NULL
 #'   divider will be overridden by a split-level section divider when
 #'   both apply to the same position in the rendered output.
 #'
-#' @inherit split_cols_by return
+#' @details When `length(vars) > 1` and when two calls to `analyze`
+#'     are done in sequence (the second with the default `nested =
+#'     TRUE`), the analyses will be combined into a multi-variable
+#'     analysis that will be reflected in the row structure of the
+#'     resulting table. In these cases, the default is to show the
+#'     label describing the variable analyzed for each of the
+#'     resulting subtables, while that is hidden by default in
+#'     one-variable cases.
 #'
-#' @details
-#' When non-`NULL`, `format` is used to specify formats for all generated rows, and can be a character vector, a
-#' function, or a list of functions. It will be repped out to the number of rows once this is calculated during the
-#' tabulation process, but will be overridden by formats specified within `rcell` calls in `afun`.
+#' # Specifying Default Formatting Behavior
+#'
+#' *Default* formatting behavior for rows generated by `afun` can be
+#' specified by one of `format` or `formats_var`. In both cases, these
+#' default formatting instructions *will not* supersede formatting
+#' specified from within `afun` at either the `rcell` or `in_rows`
+#' call levels; They will only apply to rows/cells whose formatting as
+#' returned by `afun` is either `NULL` or `"default"`.  When
+#' non-`NULL`, `format` is used to specify formats for all generated
+#' rows, and can be a character vector, a function, or a list of
+#' functions. It will be repped out to the number of rows once this is
+#' calculated during the tabulation process, but will be overridden by
+#' formats specified within `rcell` calls in `afun`.
+#'
+#' `format` can accept a format label string (see
+#' [formatters::list_valid_format_labels()]), a formatting function, an
+#' unnamed list, or a named list.
+#'
+#' When `format` is an unnamed list - or a named list where not all
+#' values of `vars` appear in the names - its elements will be repped
+#' out to the number of rows generated by `afun` (separately) within
+#' each row facet `afun` is applied within. **This includes recycling
+#' behavior, even in the case where the number of rows is not cleanly
+#' divisible by the number of specified formats**. This behavior is
+#' retained largely for legacy reasons and switching to the new
+#' named-list behavior is advised where applicable.
+#'
+#' When `format` is a named list whose names contain all values in
+#' `vars`, the elements of `format` are taken to be specific to the
+#' analysis of the corresponding variable; this allows us to specify a
+#' multi-variable analysis where e.g., the different variables are
+#' analyzed by the same `afun` but have different levels of
+#' measurement precision (and thus different formatting needs). In
+#' this case the var-specific formatting can be a single format (label
+#' string or function) or can be a named list whose names will be
+#' matched up to those of the rows generated by applying `afun` in
+#' each row facet. Matching of formats to rows is performed the same
+#' as in the `formats_var` case and is described below.
+#'
+#' When `formats_var` is non-`NULL`, it specifies the name of a list
+#' column containing formatting instructions for one or more rows
+#' `afun` will generate when applied within a row facet. This can be
+#' used when the analysis results for a single variable (e.g., `value`
+#' or `AVAL` in long-form data) should be formatted differently within
+#' different row facets (e.g., when faceting on `statistic` or
+#' `PARAMCD`). The value of `df[[formats_var]]` is assumed without
+#' verification to be constant within each row facet `afun` is applied
+#' within, and the first (list) value of the column within the row
+#' facet data will be used.
+#'
+#' In the `formats_var` case as well as the case of `format` being a
+#' named list containing the values of `vars`, after rows are created
+#' during tabulation, the default formats are matched and applied to
+#' them as follows:
+#'
+#' 1. When the generated row's name (as given by `obj_name`) matches
+#'   a name in the list, the corresponding default format is applied,
+#' 2. for those without exact matches, the default format whose name
+#'   provides *the best partial match* to each row name is applied,
+#' 3. For those without default format names that partially match
+#'   the row name, no default format is applied.
+#'
+#' Note carefully that in (2), it is the names of the list of formats
+#' that are partially matching the row names not the other way around.
+#'
+#' # The Analysis Function
 #'
 #' The analysis function (`afun`) should take as its first parameter either `x` or `df`. Whichever of these the
 #' function accepts will change the behavior when tabulation is performed as follows:
@@ -1086,6 +1155,8 @@ NULL
 #' other parameters which, *if and only if* present in the formals, will be passed to the function by the tabulation
 #' machinery. These are listed and described in [additional_fun_params].
 #'
+#' @inherit split_cols_by return
+#'
 #' @note None of the arguments described in [additional_fun_params] can be overridden via `extra_args` or when calling
 #'   [make_afun()]. `.N_col` and `.N_total` can be overridden via the `col_counts` argument to [build_table()].
 #'   Alternative values for the others must be calculated within `afun` based on a combination of extra arguments and
@@ -1124,7 +1195,9 @@ analyze <- function(lyt,
                     table_names = vars,
                     parent_name = NULL,
                     format = NULL,
+                    formats_var = NULL,
                     na_str = NA_character_,
+                    na_strs_var = NULL,
                     nested = TRUE,
                     ## can't name this na_rm symbol conflict with possible afuns!!
                     inclNAs = FALSE,
@@ -1134,6 +1207,19 @@ analyze <- function(lyt,
                     section_div = NA_character_) {
   show_labels <- match.arg(show_labels)
   subafun <- substitute(afun)
+  if (!is.null(format) && !is.null(formats_var)) {
+    stop(
+      "Cannot use 'format' and 'formats_var' arguments at ",
+      "the same time. Please choose one method for specifying ",
+      "default formatting."
+    )
+  } else if (is.null(formats_var) && !is.null(na_strs_var)) {
+    stop(
+      "Cannot use 'na_strs_var' (got ",
+      na_strs_var,
+      ") without using 'formats_var'."
+    )
+  }
   # R treats a single NA value as a logical atomic. The below
   # maps all the NAs in `var_labels` to NA_character_ required by `Split`
   # and avoids the error when `var_labels` is just c(NA).
@@ -1159,6 +1245,17 @@ analyze <- function(lyt,
     defrowlab <- var_labels
   }
 
+  ## hook up the new hotness
+  var_format_lists <- length(vars) > 1 &&
+    is.list(format) &&
+    all(vars %in% names(format))
+
+  if (var_format_lists) {
+    format <- lapply(format, function(x) FormatList(.list = x))
+    if (is.character(na_str)) {
+      na_str <- lapply(format, function(x) na_str)
+    }
+  }
   spl <- AnalyzeMultiVars(vars, var_labels,
     afun = afun,
     split_format = format,
@@ -1170,7 +1267,9 @@ analyze <- function(lyt,
     child_names = table_names,
     child_labels = show_labels,
     section_div = section_div,
-    split_name = parent_name
+    split_name = parent_name,
+    formats_var = formats_var,
+    na_strs_var = na_strs_var
   )
 
   if (nested && (is(last_rowsplit(lyt), "VAnalyzeSplit") || is(last_rowsplit(lyt), "AnalyzeMultiVars"))) {
@@ -2027,6 +2126,7 @@ list_wrap_df <- function(f) {
 #' Every layout must start with a basic table.
 #'
 #' @inheritParams constr_args
+#' @inheritParams gen_args
 #' @param show_colcounts (`logical(1)`)\cr Indicates whether the lowest level of
 #'   applied to data. `NA`, the default, indicates that the `show_colcounts`
 #'   argument(s) passed to the relevant calls to `split_cols_by*`
@@ -2096,7 +2196,9 @@ basic_table <- function(title = "",
                         colcount_format = "(N=xx)",
                         header_section_div = NA_character_,
                         top_level_section_div = NA_character_,
-                        inset = 0L) {
+                        inset = 0L,
+                        round_type = valid_round_type) {
+  round_type <- match.arg(round_type)
   inset <- as.integer(inset)
   if (is.na(inset) || inset < 0L) {
     stop("Got invalid table_inset value, must be an integer > 0")
@@ -2111,7 +2213,8 @@ basic_table <- function(title = "",
     prov_footer = prov_footer,
     header_section_div = header_section_div,
     top_level_section_div = top_level_section_div,
-    table_inset = as.integer(inset)
+    table_inset = as.integer(inset),
+    round_type = round_type
   )
 
   ## unconditional now, NA case is handled in cinfo construction
