@@ -550,6 +550,104 @@ gen_rowvalues <- function(dfpart,
   ctab
 }
 
+## return index in tbl that has best partial match to str
+## or NA_integer_ if none do
+inv_pmatch <- function(str, tbl) {
+  inds <- pmatch(tbl, str, duplicates.ok = TRUE)
+  found_inds <- which(!is.na(inds))
+  ret <- NA_integer_
+  if (length(found_inds) == 1) {
+    ret <- found_inds
+  } else if (length(found_inds) > 1) {
+    ncs <- nchar(tbl[found_inds])
+    chosen <- which.max(ncs)
+    ret <- found_inds[chosen]
+  }
+  ret
+}
+
+.got_noname_single <- function(lst) {
+  is.list(lst) && length(lst) == 1 && is.null(names(lst))
+}
+.apply_default_formats <- function(kidlst, fmtlst, nastrlst = character()) {
+  if (length(fmtlst) == 0 && length(nastrlst) == 0) {
+    return(kidlst)
+  }
+
+  if (is.null(names(kidlst))) {
+    names(kidlst) <- vapply(kidlst, obj_name, "")
+  }
+
+  if (identical(nastrlst, character())) {
+    nastrlst <- NA_character_
+  }
+
+  if (is.character(nastrlst) && length(nastrlst) >= 1) {
+    missing_nastr_val <- nastrlst
+    nastrlst <- list()
+  } else if (.got_noname_single(nastrlst)) {
+    missing_nastr_val <- nastrlst[[1]]
+    natsrlst <- list()
+  } else {
+    missing_nastr_val <- NA_character_
+  }
+
+  if (!is.list(fmtlst)) { ## appears impossible??
+    missing_fmt_val <- fmtlst
+    fmtlst <- list()
+  } else if (.got_noname_single(fmtlst)) {
+    stopifnot(is(fmtlst[[1]], "FormatSpec"))
+    missing_fmt_val <- fmtlst[[1]]
+    fmtlst <- list()
+  } else {
+    missing_fmt_val <- NULL
+  }
+
+  if (length(names(fmtlst)) > 0 || length(names(nastrlst)) > 0) {
+    missing_nastrs <- setdiff(names(fmtlst), names(nastrlst))
+    missing_fmts <- setdiff(names(nastrlst), names(fmtlst))
+  } else {
+    missing_nastrs <- names(kidlst)
+    missing_fmts <- names(kidlst)
+  }
+
+  if (length(missing_nastrs) > 0) {
+    nastrlst[missing_nastrs] <- missing_nastr_val
+  }
+  if (length(missing_fmts) > 0) {
+    fmtlst[missing_fmts] <- list(missing_fmt_val)
+  }
+
+  ## they may be in different orders, if so fix it
+  stopifnot(intersect(names(fmtlst), names(nastrlst)) == names(fmtlst))
+  nastrlst <- nastrlst[names(fmtlst)]
+
+  ## checks for exact matches first then (inverse) partial matches
+  fmt_match <- match(names(kidlst), names(fmtlst))
+  no_exact_inds <- which(is.na(fmt_match))
+  fmt_match[no_exact_inds] <- vapply(
+    names(kidlst)[no_exact_inds],
+    inv_pmatch,
+    tbl = names(fmtlst),
+    1L
+  )
+
+  toset <- which(!is.na(fmt_match))
+
+  fmts <- fmtlst[fmt_match[toset]]
+  na_strs <- nastrlst[names(fmts)]
+
+  kidlst[toset] <- mapply(function(kid, fmt, na_str) {
+    if (fmt_can_inherit(kid)) {
+      kid <- set_format_recursive(kid, fmt, na_str, override = FALSE)
+    }
+    kid
+  }, kid = kidlst[toset], fmt = fmts, na_str = na_strs, SIMPLIFY = FALSE)
+
+  kidlst
+}
+
+
 .make_analyzed_tab <- function(df,
                                alt_df,
                                alt_df_full,
@@ -566,6 +664,20 @@ gen_rowvalues <- function(dfpart,
   if (nchar(defrlabel) == 0 && !missing(partlabel) && nchar(partlabel) > 0) {
     defrlabel <- partlabel
   }
+
+  fmt <- obj_format(spl)
+  have_fmt_lst <- FALSE
+  if (is(fmt, "FormatList")) {
+    ## list for diff vars but each has one format case
+    if (length(fmt) == 1 && is.null(names(fmt))) {
+      fmt <- unlist(fmt)
+      stopifnot(is(fmt, "FormatSpec"))
+    } else { ## real format list case
+      fmt <- NULL
+      have_fmt_lst <- TRUE
+    }
+  }
+
   kids <- tryCatch(
     .make_tablerows(df,
       func = analysis_fun(spl),
@@ -573,7 +685,7 @@ gen_rowvalues <- function(dfpart,
       cinfo = cinfo,
       datcol = spl_payload(spl),
       lev = lvl + 1L,
-      format = obj_format(spl),
+      format = fmt, # obj_format(spl),
       splextra = split_exargs(spl),
       baselines = baselines,
       alt_dfpart = alt_df,
@@ -595,15 +707,46 @@ gen_rowvalues <- function(dfpart,
       call. = FALSE
     )
   }
+
+  fmtlist <- NULL
+  if (!is.null(spl_formats_var(spl))) {
+    if (is.null(spl_na_strs_var(spl))) {
+      na_strs <- character() ## case handled in .apply_default_formats
+    } else {
+      na_strs <- df[[spl_na_strs_var(spl)]][[1]]
+    }
+    fmtlist <- df[[spl_formats_var(spl)]][[1]]
+  } else if (have_fmt_lst) {
+    fmtlist <- obj_format(spl)
+    na_strs <- obj_na_str(spl)
+    if (is.character(na_strs)) {
+      na_strs <- lapply(fmtlist, function(nm) na_strs)
+      names(na_strs) <- names(fmtlist)
+    }
+  }
+
+  if (!is.null(fmtlist)) {
+    kids <- .apply_default_formats(
+      kids,
+      fmtlist,
+      na_strs
+    )
+  }
+
   lab <- obj_label(spl)
+  if (is.character(obj_na_str(spl))) {
+    final_na_str <- obj_na_str(spl)
+  } else {
+    final_na_str <- NA_character_
+  }
   ret <- TableTree(
     kids = kids,
     name = obj_name(spl),
     label = lab,
     lev = lvl,
     cinfo = cinfo,
-    format = obj_format(spl),
-    na_str = obj_na_str(spl),
+    format = if (is.null(fmtlist)) obj_format(spl) else NULL,
+    na_str = final_na_str,
     indent_mod = indent_mod(spl),
     trailing_section_div = spl_section_div(spl)
   )
@@ -1239,6 +1382,7 @@ build_table <- function(lyt, df,
                         col_total = if (is.null(alt_counts_df)) nrow(df) else nrow(alt_counts_df),
                         topleft = NULL,
                         hsep = default_hsep(),
+                        round_type = if (is(lyt, "PreDataTableLayouts")) obj_round_type(lyt) else valid_round_type,
                         ...) {
   if (!is(lyt, "PreDataTableLayouts")) {
     stop(
@@ -1356,6 +1500,7 @@ build_table <- function(lyt, df,
     main_footer(tab) <- main_footer(lyt)
     prov_footer(tab) <- prov_footer(lyt)
     header_section_div(tab) <- header_section_div(lyt)
+    obj_round_type(tab) <- round_type
   } else {
     tab <- TableTree(
       cont = ctab,
@@ -1371,7 +1516,8 @@ build_table <- function(lyt, df,
       subtitles = subtitles(lyt),
       main_footer = main_footer(lyt),
       prov_footer = prov_footer(lyt),
-      header_section_div = header_section_div(lyt)
+      header_section_div = header_section_div(lyt),
+      round_type = round_type
     )
   }
 
